==> func_adl_servicex_xaodr21-1.1.2.21.2.209.tar.gz: func_adl_servicex_xaodr21-1.1.2.21.2.209/func_adl_servicex_xaodr21/xAOD/truthevent_v1.py <==
from __future__ import annotations
import ast
from typing import Tuple, TypeVar, Iterable
from func_adl import ObjectStream, func_adl_callback, func_adl_parameterized_call
import func_adl_servicex_xaodr21

_method_map = {
    'weights': {
        'metadata_type': 'add_method_type_info',
        'type_string': 'xAOD::TruthEvent_v1',
        'method_name': 'weights',
        'return_type_element': 'float',
        'return_type_collection': 'const vector<float>',
    },
    'crossSection': {
        'metadata_type': 'add_method_type_info',
        'type_string': 'xAOD::TruthEvent_v1',
        'method_name': 'crossSection',
        'return_type': 'float',
    },
    'crossSectionError': {
        'metadata_type': 'add_method_type_info',
        'type_string': 'xAOD::TruthEvent_v1',
        'method_name': 'crossSectionError',
        'return_type': 'float',
    },
    'pdfInfo': {
        'metadata_type': 'add_method_type_info',
        'type_string': 'xAOD::TruthEvent_v1',
        'method_name': 'pdfInfo',
        'return_type': 'xAOD::TruthEvent_v1::PdfInfo',
    },
    'signalProcessVertex': {
        'metadata_type': 'add_method_type_info',
        'type_string': 'xAOD::TruthEvent_v1',
        'method_name': 'signalProcessVertex',
        'return_type': 'const xAOD::TruthVertex_v1*',
    },
    'signalProcessVertexLink': {
        'metadata_type': 'add_method_type_info',
        'type_string': 'xAOD::TruthEvent_v1',
        'method_name': 'signalProcessVertexLink',
        'return_type': 'const ElementLink<DataVector<xAOD::TruthVertex_v1>>',
    },
    'beamParticle1Link': {
        'metadata_type': 'add_method_type_info',
        'type_string': 'xAOD::TruthEvent_v1',
        'method_name': 'beamParticle1Link',
        'return_type': 'const ElementLink<DataVector<xAOD::TruthParticle_v1>>',
    },
    'beamParticle2Link': {
        'metadata_type': 'add_method_type_info',
        'type_string': 'xAOD::TruthEvent_v1',
        'method_name': 'beamParticle2Link',
        'return_type': 'const ElementLink<DataVector<xAOD::TruthParticle_v1>>',
    },
    'truthParticleLinks': {
        'metadata_type': 'add_method_type_info',
        'type_string': 'xAOD::TruthEvent_v1',
        'method_name': 'truthParticleLinks',
        'return_type_element': 'ElementLink<DataVector<xAOD::TruthParticle_v1>>',
        'return_type_collection': 'const vector<ElementLink<DataVector<xAOD::TruthParticle_v1>>>',
    },
    'nTruthParticles': {
        'metadata_type': 'add_method_type_info',
        'type_string': 'xAOD::TruthEvent_v1',
        'method_name': 'nTruthParticles',
        'return_type': 'int',
    },
    'truthParticleLink': {
        'metadata_type': 'add_method_type_info',
        'type_string': 'xAOD::TruthEvent_v1',
        'method_name': 'truthParticleLink',
        'return_type': 'const ElementLink<DataVector<xAOD::TruthParticle_v1>>',
    },
    'truthParticle': {
        'metadata_type': 'add_method_type_info',
        'type_string': 'xAOD::TruthEvent_v1',
        'method_name': 'truthParticle',
        'return_type': 'const xAOD::TruthParticle_v1*',
    },
    'truthVertexLinks': {
        'metadata_type': 'add_method_type_info',
        'type_string': 'xAOD::TruthEvent_v1',
        'method_name': 'truthVertexLinks',
        'return_type_element': 'ElementLink<DataVector<xAOD::TruthVertex_v1>>',
        'return_type_collection': 'const vector<ElementLink<DataVector<xAOD::TruthVertex_v1>>>',
    },
    'nTruthVertices': {
        'metadata_type': 'add_method_type_info',
        'type_string': 'xAOD::TruthEvent_v1',
        'method_name': 'nTruthVertices',
        'return_type': 'int',
    },
    'truthVertexLink': {
        'metadata_type': 'add_method_type_info',
        'type_string': 'xAOD::TruthEvent_v1',
        'method_name': 'truthVertexLink',
        'return_type': 'const ElementLink<DataVector<xAOD::TruthVertex_v1>>',
    },
    'truthVertex': {
        'metadata_type': 'add_method_type_info',
        'type_string': 'xAOD::TruthEvent_v1',
        'method_name': 'truthVertex',
        'return_type': 'const xAOD::TruthVertex_v1*',
    },
    'index': {
        'metadata_type': 'add_method_type_info',
        'type_string': 'xAOD::TruthEvent_v1',
        'method_name': 'index',
        'return_type': 'int',
    },
    'usingPrivateStore': {
        'metadata_type': 'add_method_type_info',
        'type_string': 'xAOD::TruthEvent_v1',
        'method_name': 'usingPrivateStore',
        'return_type': 'bool',
    },
    'usingStandaloneStore': {
        'metadata_type': 'add_method_type_info',
        'type_string': 'xAOD::TruthEvent_v1',
        'method_name': 'usingStandaloneStore',
        'return_type': 'bool',
    },
    'hasStore': {
        'metadata_type': 'add_method_type_info',
        'type_string': 'xAOD::TruthEvent_v1',
        'method_name': 'hasStore',
        'return_type': 'bool',
    },
    'hasNonConstStore': {
        'metadata_type': 'add_method_type_info',
        'type_string': 'xAOD::TruthEvent_v1',
        'method_name': 'hasNonConstStore',
        'return_type': 'bool',
    },
    'clearDecorations': {
        'metadata_type': 'add_method_type_info',
        'type_string': 'xAOD::TruthEvent_v1',
        'method_name': 'clearDecorations',
        'return_type': 'bool',
    },
    'auxdataConst': {
        'metadata_type': 'add_method_type_info',
        'type_string': 'xAOD::TruthEvent_v1',
        'method_name': 'auxdataConst',
        'return_type': 'U',
    },
    'isAvailable': {
        'metadata_type': 'add_method_type_info',
        'type_string': 'xAOD::TruthEvent_v1',
        'method_name': 'isAvailable',
        'return_type': 'bool',
    },
}


T = TypeVar('T')


def _add_method_metadata(s: ObjectStream[T], a: ast.Call) -> Tuple[ObjectStream[T], ast.Call]:
    '''Add metadata for a collection to the func_adl stream if we know about it
    '''
    assert isinstance(a.func, ast.Attribute)
    if a.func.attr in _method_map:
        s_update = s.MetaData(_method_map[a.func.attr])
        s_update = s_update.MetaData({
            'metadata_type': 'inject_code',
            'name': 'xAODTruth/versions/TruthEvent_v1.h',
            'body_includes': ["xAODTruth/versions/TruthEvent_v1.h"],
        })
        return s_update, a
    else:
        return s, a


@func_adl_callback(_add_method_metadata)
class TruthEvent_v1:
    "A class"

    def weights(self) -> func_adl_servicex_xaodr21.vector_float_.vector_float_:
        "A method"
        ...

    def crossSection(self) -> float:
        "A method"
        ...

    def crossSectionError(self) -> float:
        "A method"
        ...

    def pdfInfo(self) -> func_adl_servicex_xaodr21.xAOD.TruthEvent_v1.pdfinfo.PdfInfo:
        "A method"
        ...

    def signalProcessVertex(self) -> func_adl_servicex_xaodr21.xAOD.truthvertex_v1.TruthVertex_v1:
        "A method"
        ...

    def signalProcessVertexLink(self) -> func_adl_servicex_xaodr21.elementlink_datavector_xaod_truthvertex_v1__.ElementLink_DataVector_xAOD_TruthVertex_v1__:
        "A method"
        ...

    def beamParticle1Link(self) -> func_adl_servicex_xaodr21.elementlink_datavector_xaod_truthparticle_v1__.ElementLink_DataVector_xAOD_TruthParticle_v1__:
        "A method"
        ...

    def beamParticle2Link(self) -> func_adl_servicex_xaodr21.elementlink_datavector_xaod_truthparticle_v1__.ElementLink_DataVector_xAOD_TruthParticle_v1__:
        "A method"
        ...

    def truthParticleLinks(self) -> func_adl_servicex_xaodr21.vector_elementlink_datavector_xaod_truthparticle_v1___.vector_ElementLink_DataVector_xAOD_TruthParticle_v1___:
        "A method"
        ...

    def nTruthParticles(self) -> int:
        "A method"
        ...

    def truthParticleLink(self, index: int) -> func_adl_servicex_xaodr21.elementlink_datavector_xaod_truthparticle_v1__.ElementLink_DataVector_xAOD_TruthParticle_v1__:
        "A method"
        ...

    def truthParticle(self, index: int) -> func_adl_servicex_xaodr21.xAOD.truthparticle_v1.TruthParticle_v1:
        "A method"
        ...

    def truthVertexLinks(self) -> func_adl_servicex_xaodr21.vector_elementlink_datavector_xaod_truthvertex_v1___.vector_ElementLink_DataVector_xAOD_TruthVertex_v1___:
        "A method"
        ...

    def nTruthVertices(self) -> int:
        "A method"
        ...

    def truthVertexLink(self, index: int) -> func_adl_servicex_xaodr21.elementlink_datavector_xaod_truthvertex_v1__.ElementLink_DataVector_xAOD_TruthVertex_v1__:
        "A method"
        ...

    def truthVertex(self, index: int) -> func_adl_servicex_xaodr21.xAOD.truthvertex_v1.TruthVertex_v1:
        "A method"
        ...

    def index(self) -> int:
        "A method"
        ...

    def usingPrivateStore(self) -> bool:
        "A method"
        ...

    def usingStandaloneStore(self) -> bool:
        "A method"
        ...

    def hasStore(self) -> bool:
        "A method"
        ...

    def hasNonConstStore(self) -> bool:
        "A method"
        ...

    def clearDecorations(self) -> bool:
        "A method"
        ...

    @func_adl_parameterized_call(lambda s, a, param_1: func_adl_servicex_xaodr21.type_support.cpp_generic_1arg_callback('auxdataConst', s, a, param_1))
    @property
    def auxdataConst(self) -> func_adl_servicex_xaodr21.type_support.index_type_forwarder[str]:
        "A method"
        ...

    @func_adl_parameterized_call(lambda s, a, param_1: func_adl_servicex_xaodr21.type_support.cpp_generic_1arg_callback('isAvailable', s, a, param_1))
    @property
    def isAvailable(self) -> func_adl_servicex_xaodr21.type_support.index_type_forwarder[str]:
        "A method"
        ...

==> func_adl_servicex_xaodr21-2.0.0.21.2.231a12.tar.gz: func_adl_servicex_xaodr21-2.0.0.21.2.231a12/func_adl_servicex_xaodr21/xAOD/truthevent_v1.py <==
from __future__ import annotations
import ast
from typing import Tuple, TypeVar, Iterable
from func_adl import ObjectStream, func_adl_callback, func_adl_parameterized_call
from enum import Enum
import func_adl_servicex_xaodr21

_method_map = {
    'weights': {
        'metadata_type': 'add_method_type_info',
        'type_string': 'xAOD::TruthEvent_v1',
        'method_name': 'weights',
        'return_type_element': 'float',
        'return_type_collection': 'const vector<float>',
    },
    'crossSection': {
        'metadata_type': 'add_method_type_info',
        'type_string': 'xAOD::TruthEvent_v1',
        'method_name': 'crossSection',
        'return_type': 'float',
    },
    'crossSectionError': {
        'metadata_type': 'add_method_type_info',
        'type_string': 'xAOD::TruthEvent_v1',
        'method_name': 'crossSectionError',
        'return_type': 'float',
    },
    'pdfInfoParameter': {
        'metadata_type': 'add_method_type_info',
        'type_string': 'xAOD::TruthEvent_v1',
        'method_name': 'pdfInfoParameter',
        'return_type': 'bool',
    },
    'setPdfInfoParameter': {
        'metadata_type': 'add_method_type_info',
        'type_string': 'xAOD::TruthEvent_v1',
        'method_name': 'setPdfInfoParameter',
        'return_type': 'bool',
    },
    'pdfInfo': {
        'metadata_type': 'add_method_type_info',
        'type_string': 'xAOD::TruthEvent_v1',
        'method_name': 'pdfInfo',
        'return_type': 'xAOD::TruthEvent_v1::PdfInfo',
    },
    'heavyIonParameter': {
        'metadata_type': 'add_method_type_info',
        'type_string': 'xAOD::TruthEvent_v1',
        'method_name': 'heavyIonParameter',
        'return_type': 'bool',
    },
    'setHeavyIonParameter': {
        'metadata_type': 'add_method_type_info',
        'type_string': 'xAOD::TruthEvent_v1',
        'method_name': 'setHeavyIonParameter',
        'return_type': 'bool',
    },
    'signalProcessVertex': {
        'metadata_type': 'add_method_type_info',
        'type_string': 'xAOD::TruthEvent_v1',
        'method_name': 'signalProcessVertex',
        'return_type': 'const xAOD::TruthVertex_v1*',
    },
    'signalProcessVertexLink': {
        'metadata_type': 'add_method_type_info',
        'type_string': 'xAOD::TruthEvent_v1',
        'method_name': 'signalProcessVertexLink',
        'return_type': 'const ElementLink<DataVector<xAOD::TruthVertex_v1>>',
    },
    'beamParticle1Link': {
        'metadata_type': 'add_method_type_info',
        'type_string': 'xAOD::TruthEvent_v1',
        'method_name': 'beamParticle1Link',
        'return_type': 'const ElementLink<DataVector<xAOD::TruthParticle_v1>>',
    },
    'beamParticle2Link': {
        'metadata_type': 'add_method_type_info',
        'type_string': 'xAOD::TruthEvent_v1',
        'method_name': 'beamParticle2Link',
        'return_type': 'const ElementLink<DataVector<xAOD::TruthParticle_v1>>',
    },
    'truthParticleLinks': {
        'metadata_type': 'add_method_type_info',
        'type_string': 'xAOD::TruthEvent_v1',
        'method_name': 'truthParticleLinks',
        'return_type_element': 'ElementLink<DataVector<xAOD::TruthParticle_v1>>',
        'return_type_collection': 'const vector<ElementLink<DataVector<xAOD::TruthParticle_v1>>>',
    },
    'nTruthParticles': {
        'metadata_type': 'add_method_type_info',
        'type_string': 'xAOD::TruthEvent_v1',
        'method_name': 'nTruthParticles',
        'return_type': 'int',
    },
    'truthParticleLink': {
        'metadata_type': 'add_method_type_info',
        'type_string': 'xAOD::TruthEvent_v1',
        'method_name': 'truthParticleLink',
        'return_type': 'const ElementLink<DataVector<xAOD::TruthParticle_v1>>',
    },
    'truthParticle': {
        'metadata_type': 'add_method_type_info',
        'type_string': 'xAOD::TruthEvent_v1',
        'method_name': 'truthParticle',
        'return_type': 'const xAOD::TruthParticle_v1*',
    },
    'truthVertexLinks': {
        'metadata_type': 'add_method_type_info',
        'type_string': 'xAOD::TruthEvent_v1',
        'method_name': 'truthVertexLinks',
        'return_type_element': 'ElementLink<DataVector<xAOD::TruthVertex_v1>>',
        'return_type_collection': 'const vector<ElementLink<DataVector<xAOD::TruthVertex_v1>>>',
    },
    'nTruthVertices': {
        'metadata_type': 'add_method_type_info',
        'type_string': 'xAOD::TruthEvent_v1',
        'method_name': 'nTruthVertices',
        'return_type': 'int',
    },
    'truthVertexLink': {
        'metadata_type': 'add_method_type_info',
        'type_string': 'xAOD::TruthEvent_v1',
        'method_name': 'truthVertexLink',
        'return_type': 'const ElementLink<DataVector<xAOD::TruthVertex_v1>>',
    },
    'truthVertex': {
        'metadata_type': 'add_method_type_info',
        'type_string': 'xAOD::TruthEvent_v1',
        'method_name': 'truthVertex',
        'return_type': 'const xAOD::TruthVertex_v1*',
    },
    'index': {
        'metadata_type': 'add_method_type_info',
        'type_string': 'xAOD::TruthEvent_v1',
        'method_name': 'index',
        'return_type': 'int',
    },
    'usingPrivateStore': {
        'metadata_type': 'add_method_type_info',
        'type_string': 'xAOD::TruthEvent_v1',
        'method_name': 'usingPrivateStore',
        'return_type': 'bool',
    },
    'usingStandaloneStore': {
        'metadata_type': 'add_method_type_info',
        'type_string': 'xAOD::TruthEvent_v1',
        'method_name': 'usingStandaloneStore',
        'return_type': 'bool',
    },
    'hasStore': {
        'metadata_type': 'add_method_type_info',
        'type_string': 'xAOD::TruthEvent_v1',
        'method_name': 'hasStore',
        'return_type': 'bool',
    },
    'hasNonConstStore': {
        'metadata_type': 'add_method_type_info',
        'type_string': 'xAOD::TruthEvent_v1',
        'method_name': 'hasNonConstStore',
        'return_type': 'bool',
    },
    'clearDecorations': {
        'metadata_type': 'add_method_type_info',
        'type_string': 'xAOD::TruthEvent_v1',
        'method_name': 'clearDecorations',
        'return_type': 'bool',
    },
    'auxdataConst': {
        'metadata_type': 'add_method_type_info',
        'type_string': 'xAOD::TruthEvent_v1',
        'method_name': 'auxdataConst',
        'return_type': 'U',
    },
    'isAvailable': {
        'metadata_type': 'add_method_type_info',
        'type_string': 'xAOD::TruthEvent_v1',
        'method_name': 'isAvailable',
        'return_type': 'bool',
    },
}

_enum_map = {      
}

T = TypeVar('T')


def _add_method_metadata(s: ObjectStream[T], a: ast.Call) -> Tuple[ObjectStream[T], ast.Call]:
    '''Add metadata for a collection to the func_adl stream if we know about it
    '''
    assert isinstance(a.func, ast.Attribute)
    if a.func.attr in _method_map:
        s_update = s.MetaData(_method_map[a.func.attr])
        s_update = s_update.MetaData({
            'metadata_type': 'inject_code',
            'name': 'xAODTruth/versions/TruthEvent_v1.h',
            'body_includes': ["xAODTruth/versions/TruthEvent_v1.h"],
        })
        for md in _enum_map.get(a.func.attr, []):
            s_update = s_update.MetaData(md)
        return s_update, a
    else:
        return s, a


@func_adl_callback(_add_method_metadata)
class TruthEvent_v1:
    "A class"

    class PdfParam(Enum):
        PDGID1 = 0
        PDGID2 = 1
        PDFID1 = 2
        PDFID2 = 3
        X1 = 4
        X2 = 5
        SCALE = 6
        Q = 6
        PDF1 = 7
        PDF2 = 8
        XF1 = 7
        XF2 = 8

    class HIParam(Enum):
        NCOLLHARD = 0
        NPARTPROJ = 1
        NPARTTARG = 2
        NCOLL = 3
        SPECTATORNEUTRONS = 4
        SPECTATORPROTONS = 5
        NNWOUNDEDCOLLISIONS = 6
        NWOUNDEDNCOLLISIONS = 7
        NWOUNDEDNWOUNDEDCOLLISIONS = 8
        IMPACTPARAMETER = 9
        EVENTPLANEANGLE = 10
        ECCENTRICITY = 11
        SIGMAINELNN = 12
        CENTRALITY = 13


    def weights(self) -> func_adl_servicex_xaodr21.vector_float_.vector_float_:
        "A method"
        ...

    def crossSection(self) -> float:
        "A method"
        ...

    def crossSectionError(self) -> float:
        "A method"
        ...

    def pdfInfoParameter(self, value: int, parameter: func_adl_servicex_xaodr21.xAOD.truthevent_v1.TruthEvent_v1.PdfParam) -> bool:
        "A method"
        ...

    def setPdfInfoParameter(self, value: int, parameter: func_adl_servicex_xaodr21.xAOD.truthevent_v1.TruthEvent_v1.PdfParam) -> bool:
        "A method"
        ...

    def pdfInfo(self) -> func_adl_servicex_xaodr21.xAOD.TruthEvent_v1.pdfinfo.PdfInfo:
        "A method"
        ...

    def heavyIonParameter(self, value: int, parameter: func_adl_servicex_xaodr21.xAOD.truthevent_v1.TruthEvent_v1.HIParam) -> bool:
        "A method"
        ...

    def setHeavyIonParameter(self, value: int, parameter: func_adl_servicex_xaodr21.xAOD.truthevent_v1.TruthEvent_v1.HIParam) -> bool:
        "A method"
        ...

    def signalProcessVertex(self) -> func_adl_servicex_xaodr21.xAOD.truthvertex_v1.TruthVertex_v1:
        "A method"
        ...

    def signalProcessVertexLink(self) -> func_adl_servicex_xaodr21.elementlink_datavector_xaod_truthvertex_v1__.ElementLink_DataVector_xAOD_TruthVertex_v1__:
        "A method"
        ...

    def beamParticle1Link(self) -> func_adl_servicex_xaodr21.elementlink_datavector_xaod_truthparticle_v1__.ElementLink_DataVector_xAOD_TruthParticle_v1__:
        "A method"
        ...

    def beamParticle2Link(self) -> func_adl_servicex_xaodr21.elementlink_datavector_xaod_truthparticle_v1__.ElementLink_DataVector_xAOD_TruthParticle_v1__:
        "A method"
        ...

    def truthParticleLinks(self) -> func_adl_servicex_xaodr21.vector_elementlink_datavector_xaod_truthparticle_v1___.vector_ElementLink_DataVector_xAOD_TruthParticle_v1___:
        "A method"
        ...

    def nTruthParticles(self) -> int:
        "A method"
        ...

    def truthParticleLink(self, index: int) -> func_adl_servicex_xaodr21.elementlink_datavector_xaod_truthparticle_v1__.ElementLink_DataVector_xAOD_TruthParticle_v1__:
        "A method"
        ...

    def truthParticle(self, index: int) -> func_adl_servicex_xaodr21.xAOD.truthparticle_v1.TruthParticle_v1:
        "A method"
        ...

    def truthVertexLinks(self) -> func_adl_servicex_xaodr21.vector_elementlink_datavector_xaod_truthvertex_v1___.vector_ElementLink_DataVector_xAOD_TruthVertex_v1___:
        "A method"
        ...

    def nTruthVertices(self) -> int:
        "A method"
        ...

    def truthVertexLink(self, index: int) -> func_adl_servicex_xaodr21.elementlink_datavector_xaod_truthvertex_v1__.ElementLink_DataVector_xAOD_TruthVertex_v1__:
        "A method"
        ...

    def truthVertex(self, index: int) -> func_adl_servicex_xaodr21.xAOD.truthvertex_v1.TruthVertex_v1:
        "A method"
        ...

    def index(self) -> int:
        "A method"
        ...

    def usingPrivateStore(self) -> bool:
        "A method"
        ...

    def usingStandaloneStore(self) -> bool:
        "A method"
        ...

    def hasStore(self) -> bool:
        "A method"
        ...

    def hasNonConstStore(self) -> bool:
        "A method"
        ...

    def clearDecorations(self) -> bool:
        "A method"
        ...

    @func_adl_parameterized_call(lambda s, a, param_1: func_adl_servicex_xaodr21.type_support.cpp_generic_1arg_callback('auxdataConst', s, a, param_1))
    @property
    def auxdataConst(self) -> func_adl_servicex_xaodr21.type_support.index_type_forwarder[func_adl_servicex_xaodr21.str.str]:
        "A method"
        ...

    @func_adl_parameterized_call(lambda s, a, param_1: func_adl_servicex_xaodr21.type_support.cpp_generic_1arg_callback('isAvailable', s, a, param_1))
    @property
    def isAvailable(self) -> func_adl_servicex_xaodr21.type_support.index_type_forwarder[func_adl_servicex_xaodr21.str.str]:
        "A method"
        ...
